@@ -18,7 +18,7 @@ from python3_commons.object_storage import get_s3_client
 logger = logging.getLogger(__name__)
 
 
-async def write_audit_data(settings: S3Settings, key: str, data: bytes):
+def write_audit_data_sync(settings: S3Settings, key: str, data: bytes):
     if settings.s3_secret_access_key:
         try:
             client = get_s3_client(settings)
@@ -33,6 +33,10 @@ async def write_audit_data(settings: S3Settings, key: str, data: bytes):
         logger.debug(f'S3 is not configured, not storing object in storage: {key}')
 
 
+async def write_audit_data(settings: S3Settings, key: str, data: bytes):
+    write_audit_data_sync(settings, key, data)
+
+
 async def archive_audit_data(root_path: str = 'audit'):
     now = datetime.now(tz=UTC) - timedelta(days=1)
     year = now.year
@@ -41,7 +45,7 @@ async def archive_audit_data(root_path: str = 'audit'):
     bucket_name = s3_settings.s3_bucket
     fo = BytesIO()
     object_names = []
-    date_path = object_storage.get_absolute_path(f'{root_path}/{year}/{month:02}/{day:02}')
+    date_path = f'{root_path}/{year}/{month:02}/{day:02}'
 
     with tarfile.open(fileobj=fo, mode='w|bz2') as archive:
         if objects := object_storage.get_objects(bucket_name, date_path, recursive=True):
